.. image:: https://travis-ci.org/rkhleics/wagtailmenus.svg?branch=master
        :alt: Build Status
        :target: https://travis-ci.org/rkhleics/wagtailmenus

.. image:: https://img.shields.io/pypi/v/wagtailmenus.svg
        :alt: PyPi Version
        :target: https://pypi.python.org/pypi/wagtailmenus

.. image:: https://codecov.io/gh/rkhleics/wagtailmenus/branch/master/graph/badge.svg
        :alt: Code coverage
        :target: https://codecov.io/gh/rkhleics/wagtailmenus

============
wagtailmenus
============

wagtailmenus is an extension for Torchbox's `Wagtail CMS <https://github.com/torchbox/wagtail>`_ to help you manage and render multi-level navigation and simple flat menus in a consistent, flexible way.

The current version is compatible with Wagtail 1.5 to 1.12 and Python 2.7, 3.3, 3.4, 3.5 and 3.6.

.. image:: https://raw.githubusercontent.com/rkhleics/wagtailmenus/master/docs/source/_static/images/repeating-item.png

What does it do?
================

To find out more about what wagtailmenus does and why, check out the `Overview and key concepts <http://wagtailmenus.readthedocs.io/en/stable/overview.html>`_ section of the documentation.


How do I use it?
================

For everything you need to get up and running with wagtailmenus, `view the official documentation <http://wagtailmenus.readthedocs.io/>`_.


How do I contribute?
====================

Want to contribute to wagtailmenus? We'd be happy to have you! You should start by taking a look at our `Contributor guidelines <http://wagtailmenus.readthedocs.io/en/stable/contributing/index.html>`_

We also welcome translations. Translations should be submitted through `Transifex <https://www.transifex.com/rkhleics/wagtailmenus/>`_.
